==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/Glue/StopTrigger.pm <==

package Paws::Glue::StopTrigger;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StopTrigger');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::StopTriggerResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::StopTrigger - Arguments for method StopTrigger on Paws::Glue

=head1 DESCRIPTION

This class represents the parameters used for calling the method StopTrigger on the 
AWS Glue service. Use the attributes of this class
as arguments to method StopTrigger.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to StopTrigger.

As an example:

  $service_obj->StopTrigger(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the trigger to stop.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StopTrigger in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/Glue/StopTrigger.pm <==

package Paws::Glue::StopTrigger;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StopTrigger');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::StopTriggerResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::StopTrigger - Arguments for method StopTrigger on L<Paws::Glue>

=head1 DESCRIPTION

This class represents the parameters used for calling the method StopTrigger on the
L<AWS Glue|Paws::Glue> service. Use the attributes of this class
as arguments to method StopTrigger.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to StopTrigger.

=head1 SYNOPSIS

    my $glue = Paws->service('Glue');
    my $StopTriggerResponse = $glue->StopTrigger(
      Name => 'MyNameString',

    );

    # Results:
    my $Name = $StopTriggerResponse->Name;

    # Returns a L<Paws::Glue::StopTriggerResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/glue/StopTrigger>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the trigger to stop.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StopTrigger in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
